==> job-scheduler_23.7.tar.xz: BUILD/translations/job-scheduler_he_IL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he_IL">
<context>
    <name>CronModel</name>
    <message>
        <location filename="../CronModel.cpp" line="112"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="114"/>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="116"/>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
</context>
<context>
    <name>ExecuteList</name>
    <message>
        <location filename="../ExecuteList.cpp" line="39"/>
        <source>Max Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="41"/>
        <source>Max Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="43"/>
        <source>Select</source>
        <translation>בחירה</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="48"/>
        <source>&amp;Update</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExecuteModel</name>
    <message>
        <location filename="../ExecuteModel.cpp" line="62"/>
        <source>Execute Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="64"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="66"/>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="68"/>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="51"/>
        <source>&amp;Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="54"/>
        <source>&amp;Variables</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="57"/>
        <source>&amp;Job List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="99"/>
        <location filename="../MainWindow.cpp" line="191"/>
        <location filename="../MainWindow.cpp" line="236"/>
        <location filename="../MainWindow.cpp" line="256"/>
        <location filename="../MainWindow.cpp" line="325"/>
        <source>Job Scheduler</source>
        <translation>מתזמן משימות</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="124"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="125"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="128"/>
        <source>&amp;New Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="129"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="132"/>
        <source>&amp;Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="133"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="135"/>
        <source>&amp;Save</source>
        <translation>&amp;שמירה</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="136"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="139"/>
        <source>Start as &amp;Root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="141"/>
        <source>Start as &amp;Regular user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="142"/>
        <source>Ctrl+U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="145"/>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="146"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="153"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="154"/>
        <source>Edit</source>
        <translation>עריכה</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="156"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="157"/>
        <source>Ctrl+X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="159"/>
        <source>&amp;Copy</source>
        <translation>ה&amp;עתקה</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="160"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="162"/>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="163"/>
        <source>Ctrl+V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="166"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="167"/>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="178"/>
        <location filename="../MainWindow.cpp" line="180"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="179"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="237"/>
        <source>Not saved since last change.
Are you OK to reload?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="325"/>
        <source>Not saved since last change.
Are you OK to exit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>About Job Scheduler</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="339"/>
        <source>&lt;b&gt;Job Scheduler&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="339"/>
        <source>Version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="340"/>
        <source>Job Scheduler is based upon qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="343"/>
        <source>Original project page: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="347"/>
        <source>MX project page: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="352"/>
        <source>%1 License</source>
        <translation>רישיון של %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>רישיון</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>יומן שינויים</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../SaveDialog.cpp" line="19"/>
        <source>Save New Schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="32"/>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="40"/>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="41"/>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
</context>
<context>
    <name>TCommandEdit</name>
    <message>
        <location filename="../TCommandEdit.cpp" line="41"/>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="49"/>
        <source>Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="53"/>
        <source>Time String E&amp;ditor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="57"/>
        <source>Command:</source>
        <translation>פקודה:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="63"/>
        <source>Comment:</source>
        <translation>הערה:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="66"/>
        <source>Job Schedule:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="128"/>
        <source>Time Format Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="146"/>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="148"/>
        <source>Tomorrow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TimeDialog</name>
    <message>
        <location filename="../TimeDialog.cpp" line="76"/>
        <source>time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="81"/>
        <source>Minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="93"/>
        <source>Hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="99"/>
        <source>AM </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="105"/>
        <source>PM </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="112"/>
        <source>Day</source>
        <translation>יום</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="127"/>
        <source>Month</source>
        <translation>חודש</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="141"/>
        <source>Week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="153"/>
        <source>Simple</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="167"/>
        <source>Enable Literal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="169"/>
        <source>&amp;Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="170"/>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="171"/>
        <source>&amp;Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VariableEdit</name>
    <message>
        <location filename="../VariableEdit.cpp" line="47"/>
        <source>Variables</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="52"/>
        <source>Mail:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="53"/>
        <source>Don&apos;t send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="54"/>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="55"/>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="67"/>
        <source>&amp;New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="70"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="78"/>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="83"/>
        <source>Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="86"/>
        <source>Comment:</source>
        <translation>הערה:</translation>
    </message>
</context>
<context>
    <name>VariableModel</name>
    <message>
        <location filename="../VariableModel.cpp" line="37"/>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <location filename="../VariableModel.cpp" line="39"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> job-scheduler_24.3.tar.xz: BUILD/translations/job-scheduler_he_IL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he_IL">
<context>
    <name>CronModel</name>
    <message>
        <location filename="../CronModel.cpp" line="112"/>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="114"/>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="116"/>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
</context>
<context>
    <name>ExecuteList</name>
    <message>
        <location filename="../ExecuteList.cpp" line="39"/>
        <source>Max Item</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="41"/>
        <source>Max Date</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="43"/>
        <source>Select</source>
        <translation>בחירה</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="48"/>
        <source>&amp;Update</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ExecuteModel</name>
    <message>
        <location filename="../ExecuteModel.cpp" line="62"/>
        <source>Execute Time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="64"/>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="66"/>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="68"/>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="51"/>
        <source>&amp;Command</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="54"/>
        <source>&amp;Variables</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="57"/>
        <source>&amp;Job List</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="99"/>
        <location filename="../MainWindow.cpp" line="191"/>
        <location filename="../MainWindow.cpp" line="236"/>
        <location filename="../MainWindow.cpp" line="256"/>
        <location filename="../MainWindow.cpp" line="325"/>
        <source>Job Scheduler</source>
        <translation>מתזמן משימות</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="124"/>
        <source>&amp;File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="125"/>
        <source>File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="128"/>
        <source>&amp;New Item</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="129"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="132"/>
        <source>&amp;Reload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="133"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="135"/>
        <source>&amp;Save</source>
        <translation>&amp;שמירה</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="136"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="139"/>
        <source>Start as &amp;Root</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="141"/>
        <source>Start as &amp;Regular user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="142"/>
        <source>Ctrl+U</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="145"/>
        <source>E&amp;xit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="146"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="153"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="154"/>
        <source>Edit</source>
        <translation>עריכה</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="156"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="157"/>
        <source>Ctrl+X</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="159"/>
        <source>&amp;Copy</source>
        <translation>ה&amp;עתקה</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="160"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="162"/>
        <source>&amp;Paste</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="163"/>
        <source>Ctrl+V</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="166"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="167"/>
        <source>Del</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="178"/>
        <location filename="../MainWindow.cpp" line="180"/>
        <source>&amp;Help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="179"/>
        <source>&amp;About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="237"/>
        <source>Not saved since last change.
Are you OK to reload?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="325"/>
        <source>Not saved since last change.
Are you OK to exit?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>About Job Scheduler</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="339"/>
        <source>&lt;b&gt;Job Scheduler&lt;/b&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="339"/>
        <source>Version: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="340"/>
        <source>Job Scheduler is based upon qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="343"/>
        <source>Original project page: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="347"/>
        <source>MX project page: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="352"/>
        <source>%1 License</source>
        <translation>רישיון של %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>רישיון</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>יומן שינויים</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../SaveDialog.cpp" line="19"/>
        <source>Save New Schedule</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="32"/>
        <source>User:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="40"/>
        <source>&amp;OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="41"/>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
</context>
<context>
    <name>TCommandEdit</name>
    <message>
        <location filename="../TCommandEdit.cpp" line="41"/>
        <source>User:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="49"/>
        <source>Time:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="53"/>
        <source>Time String E&amp;ditor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="57"/>
        <source>Command:</source>
        <translation>פקודה:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="63"/>
        <source>Comment:</source>
        <translation>הערה:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="66"/>
        <source>Job Schedule:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="128"/>
        <source>Time Format Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="146"/>
        <source>Today</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="148"/>
        <source>Tomorrow</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimeDialog</name>
    <message>
        <location filename="../TimeDialog.cpp" line="76"/>
        <source>time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="81"/>
        <source>Minute</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="93"/>
        <source>Hour</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="99"/>
        <source>AM </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="105"/>
        <source>PM </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="112"/>
        <source>Day</source>
        <translation>יום</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="127"/>
        <source>Month</source>
        <translation>חודש</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="141"/>
        <source>Week</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="153"/>
        <source>Simple</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="167"/>
        <source>Enable Literal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="169"/>
        <source>&amp;Reset</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="170"/>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="171"/>
        <source>&amp;Ok</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VariableEdit</name>
    <message>
        <location filename="../VariableEdit.cpp" line="47"/>
        <source>Variables</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="52"/>
        <source>Mail:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="53"/>
        <source>Don&apos;t send</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="54"/>
        <source>Send</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="55"/>
        <source>To</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="67"/>
        <source>&amp;New</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="70"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="78"/>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="83"/>
        <source>Value:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="86"/>
        <source>Comment:</source>
        <translation>הערה:</translation>
    </message>
</context>
<context>
    <name>VariableModel</name>
    <message>
        <location filename="../VariableModel.cpp" line="37"/>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <location filename="../VariableModel.cpp" line="39"/>
        <source>Value</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
